/////////////////////////////////////////////////////////////////////////////
//
//   Copyright (C) CADBAS GmbH   All rights reserved.
//
//   Name         $Author$
//   Last change  $Date$
//   Tag          $Name$
//   Repository   $Source$
//   Version      $Revision$
//
/////////////////////////////////////////////////////////////////////////////

//---------------------------------------------------------------------------
// System-Includes
//---------------------------------------------------------------------------

//---------------------------------------------------------------------------
// Qt-Includes
//---------------------------------------------------------------------------
#include <QStandardItemModel>

//---------------------------------------------------------------------------
// CADBAS-Includes
//---------------------------------------------------------------------------
#include <menu_widget_action.hpp>
#include <menu_multiple_columns_tree_view.hpp>

//---------------------------------------------------------------------------
// Defines
//---------------------------------------------------------------------------

//===========================================================================
const QString Cmenu_widget_action::_class_name = "Cmenu_widget_action";

//---------------------------------------------------------------------------
// public features
//---------------------------------------------------------------------------

//---------------------------------------------------------------------------
Cmenu_widget_action::Cmenu_widget_action (QWidget *parent)
           : QWidgetAction(parent)
{

   _tree_view = 0;

} // Konstruktor

//---------------------------------------------------------------------------
Cmenu_widget_action::~Cmenu_widget_action ()
{
   if (_tree_view)
     _tree_view->deleteLater();

   _tree_view = 0;

} // Destruktor

//---------------------------------------------------------------------------
void Cmenu_widget_action::make(const int &rows, const int &columns)
{
    // Treeview erzeugen
    _tree_view  = new Cmenu_multiple_columns_tree_view((QWidget*)parent());
    _tree_view->make();

    // Model erzeugen
    QStandardItemModel *standard_item_model =
                                             new QStandardItemModel(_tree_view);

    _tree_view->setModel(standard_item_model);

    // Spalten und Zeilen vorbereiten
    standard_item_model->insertColumns(0,columns);
    standard_item_model->insertRows   (0,rows);

    // Widget setzen
    setDefaultWidget(_tree_view);
}

//---------------------------------------------------------------------------
Cmenu_multiple_columns_tree_view *Cmenu_widget_action::get_tree_view()
{
    return _tree_view;
}

//---------------------------------------------------------------------------
void Cmenu_widget_action::resize_tree_view()
{
    // Groesse optimieren
    int i = 0;
    int w = 0;
    int h = 0;

    // Spaltenbreiten minimieren und Breiten zusammenrechnen
    for (i = 0; i < _tree_view->model()->columnCount(); i++)
    {
      _tree_view->resizeColumnToContents(i);
      w += _tree_view->columnWidth(i);
    }

    // Hoehe der Zeilen addieren
    QStandardItemModel *model = (QStandardItemModel *)_tree_view->model();
    QModelIndex index;
    
    for (i = 0; i < model->rowCount(); i++)
    {
      index = model->index(i,0);
      h += _tree_view->row_height(index);
    }        

    // Groesse anpassen
    _tree_view->setFixedSize(w, h);
}

//---------------------------------------------------------------------------
// protected features
//---------------------------------------------------------------------------

//---------------------------------------------------------------------------

//---------------------------------------------------------------------------
// private features
//---------------------------------------------------------------------------

//---------------------------------------------------------------------------
//---------------------------------------------------------------------------
// End of menu_widget_action.cpp
